@@ -1,16 +1,19 @@
-//! [GET /.well-known/matrix/server](https://matrix.org/docs/spec/server_server/r0.1.3#get-well-known-matrix-server)
+//! `GET /.well-known/matrix/server` ([spec])
+//!
+//! [spec]: https://spec.matrix.org/v1.2/server-server-api/#getwell-knownmatrixserver
 
 use ruma_api::ruma_api;
-use ruma_identifiers::ServerNameBox;
+use ruma_identifiers::ServerName;
 
 ruma_api! {
     metadata: {
         description: "Get discovery information about the domain.",
         method: GET,
         name: "discover_homeserver",
-        path: "/.well-known/matrix/server",
+        stable_path: "/.well-known/matrix/server",
         rate_limited: false,
         authentication: None,
+        added: 1.0,
     }
 
     #[derive(Default)]
@@ -19,7 +22,7 @@ ruma_api! {
     response: {
         /// The server name to delegate server-server communications to, with optional port.
         #[serde(rename = "m.server")]
-        pub server: ServerNameBox,
+        pub server: Box<ServerName>,
     }
 }
 
@@ -32,7 +35,7 @@ impl Request {
 
 impl Response {
     /// Creates a new `Response` with the given homeserver.
-    pub fn new(server: ServerNameBox) -> Self {
+    pub fn new(server: Box<ServerName>) -> Self {
         Self { server }
     }
 }
